"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ns_common_1 = require("ns-common");
const querystring = require("querystring");
const moment = require("moment");
const debug = require('debug')('findata:gapi');
const baseUrl = 'https://finance.google.com/finance/getprices?';
/**
 * @class
 * @classdesc {@link https://www.google.com/intl/zh-CN/googlefinance/disclaimer/ |谷歌接口说明}
 */
class GoogleFinance {
    /**
    * 获取历史数据
    */
    static getHistory(reqParam) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!reqParam.f) {
                reqParam.f = 'd,o,c,h,l,v';
            }
            const url = baseUrl + querystring.stringify(reqParam);
            debug('getHistory url: ', url);
            const res = yield ns_common_1.Util.fetch(url);
            const text = yield res.text();
            // 数据转换为数组
            const array = text.split('\n');
            // 去掉头部信息
            const tickArray = array.slice(8, array.length - 1);
            if (tickArray.length === 0) {
                return [];
            }
            const colName = array[4].split('=')[1];
            const intervalRow = array[3];
            const columnArray = colName.split(',');
            const interval = Number(intervalRow.split('=')[1]);
            // console.log(columnArray);
            const firstColumn = tickArray[0].split(',');
            let baseTime = 0;
            const results = [];
            for (let i = 0; i < tickArray.length; i++) {
                const txt = tickArray[i];
                const component = txt.split(',');
                let tradeTime = Number(component[0]);
                if (isNaN(tradeTime)) {
                    const timeString = component[0];
                    tradeTime = Number(timeString.substring(1, timeString.length));
                    baseTime = tradeTime;
                }
                else {
                    tradeTime = baseTime + (tradeTime * interval);
                }
                tradeTime *= 1000;
                const utc = moment(tradeTime);
                const date = utc.format('YYYY-MM-DD HH:mm:ss');
                const tickComponent = txt.split(',');
                const tickData = { 'time': tradeTime, 'symbol': reqParam.q };
                for (let j = 1; j < columnArray.length; j++) {
                    const columnName = columnArray[j];
                    tickData[columnName.toLowerCase()] = Number(tickComponent[j]);
                }
                // console.log(tickData);
                results.push(tickData);
            }
            return results;
        });
    }
}
exports.GoogleFinance = GoogleFinance;
