"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const types_1 = require("../types");
const ns_types_1 = require("ns-types");
const ns_common_1 = require("ns-common");
const ns_store_1 = require("ns-store");
const lodash_1 = require("lodash");
const debug = require('debug')('findata:hema');
const baseUrl = 'https://hesonogoma.com/stocks/';
const authBaseUrl = 'https://trial:PW%4020170129@hesonogoma.com/stocks/';
/**
 * @class
 * @classdesc {@link https://hesonogoma.com/stocks/ |hesonogoma接口}
 */
class Hesonogoma {
    constructor() {
        /**
         * 株価一覧表
         */
        this.Price = types_1.HemaPrice;
        /**
         * 投資指標データ
         */
        this.Data = types_1.HemaData;
    }
    /**
    * 获取接口数据
    */
    getFindInfo(url) {
        return __awaiter(this, void 0, void 0, function* () {
            if (url) {
                const res = yield ns_common_1.Util.fetch(url);
                debug('getFindInfo url: ', url);
                const jsonRes = yield res.json();
                if (Object.keys(jsonRes).length !== 0) {
                    return jsonRes[Object.keys(jsonRes)[0]];
                }
                return null;
            }
        });
    }
    /**
     * 株価一覧表を取得する
     */
    getFindPriceInfo(type) {
        const url = (types_1.HemaType.PriceType[type].auth ? authBaseUrl : baseUrl) + types_1.HemaType.PriceType[type].url;
        return this.getFindInfo(url);
    }
    /**
     *投資指標データを取得する
     */
    getFindDataInfo(type) {
        const url = (types_1.HemaType.DataType[type].auth ? authBaseUrl : baseUrl) + types_1.HemaType.DataType[type].url;
        return this.getFindInfo(url);
    }
    /**
     *TSEの全株を取得する
     */
    getTseStocks() {
        return __awaiter(this, void 0, void 0, function* () {
            let symbols = yield this.getFindDataInfo(types_1.HemaData.All);
            symbols = lodash_1.filter(symbols, (symbol) => {
                return symbol[2] === '東証一部'
                    || symbol[2] === '東証二部'
                    || symbol[2] === 'JQS'
                    || symbol[2] === '東証マザ';
            });
            const symbolInfoList = new Array();
            for (const sym of symbols) {
                const currMarket = types_1.MarketMap.find((o) => o.name === sym[2]);
                const currSector = ns_store_1.Store.data.SectorList.find((o) => o.name === sym[3]);
                const symbolInfo = {
                    symbol: sym[0],
                    exchange: 'TSE',
                    type: ns_types_1.SymbolType.stock,
                    name: sym[1],
                    market: currMarket ? currMarket.code : '',
                    sector: currSector ? currSector.code : '',
                };
                symbolInfoList.push(symbolInfo);
            }
            return symbolInfoList;
        });
    }
}
__decorate([
    ns_common_1.tryCatch('获取接口数据')
], Hesonogoma.prototype, "getFindInfo", null);
__decorate([
    ns_common_1.tryCatch('株価一覧表を取得する')
], Hesonogoma.prototype, "getFindPriceInfo", null);
__decorate([
    ns_common_1.tryCatch('投資指標データを取得する')
], Hesonogoma.prototype, "getFindDataInfo", null);
__decorate([
    ns_common_1.tryCatch('TSEの全株を取得する')
], Hesonogoma.prototype, "getTseStocks", null);
exports.Hesonogoma = Hesonogoma;
