"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ns_common_1 = require("ns-common");
const cio = require("cheerio");
const baseUrl = 'http://k-db.com/stocks/';
var Timeframe;
(function (Timeframe) {
    Timeframe["M5"] = "5m";
    Timeframe["M15"] = "15m";
    Timeframe["M30"] = "30m";
    Timeframe["H1"] = "1h";
    Timeframe["H4"] = "4h";
})(Timeframe = exports.Timeframe || (exports.Timeframe = {}));
/**
 * @class
 * @classdesc {@link http://k-db.com/stocks/ |Kdb接口}
 */
class Kdb {
    /**
    * 获取历史数据
    */
    getHistory(symbol, timeframe) {
        let url = baseUrl + symbol;
        if (url.indexOf('-T') === -1) {
            url += '-T';
        }
        if (timeframe) {
            url += '/' + timeframe;
        }
        url += '?download=csv';
        return ns_common_1.Util.getCsvData(url);
    }
    /**
     * 获取商品信息(描述信息)
     */
    getSymbolInfo(symbol) {
        return __awaiter(this, void 0, void 0, function* () {
            let url = baseUrl + symbol;
            if (url.indexOf('-T') === -1) {
                url += '-T';
            }
            const resPromise = yield ns_common_1.Util.fetch(url);
            const res = yield resPromise.text();
            const $ = cio.load(res);
            const symbolInfo = {};
            symbolInfo.symbol = symbol;
            symbolInfo.description = $('h1').text();
            return symbolInfo;
        });
    }
}
exports.Kdb = Kdb;
