"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const api_1 = require("./api");
exports.Kdb = api_1.Kdb;
exports.Hesonogoma = api_1.Hesonogoma;
exports.GoogleFinance = api_1.GoogleFinance;
const ns_store_1 = require("ns-store");
const ns_common_1 = require("ns-common");
const lodash_1 = require("lodash");
const sequelize_typescript_1 = require("sequelize-typescript");
const moment = require("moment");
const technicalindicators_1 = require("technicalindicators");
const assert = require("power-assert");
const debug = require('debug')('findata:main');
/**
 * 财经数据实现类
 */
class DataProvider {
    constructor(config) {
        if (config) {
            assert(config.database, 'config.database required.');
            this.config = config;
        }
    }
    init() {
        return __awaiter(this, void 0, void 0, function* () {
            yield ns_store_1.Store.init(this.config);
        });
    }
    close() {
        return __awaiter(this, void 0, void 0, function* () {
            yield ns_store_1.Store.close();
        });
    }
    /**
    * 获取市场数据
    */
    getMarkets() {
        return __awaiter(this, void 0, void 0, function* () {
            debug('getMarkets，获取市场数据方法[启动]');
            // 交易股票列表取得
            const symbolList = yield this.getSymbolList();
            // filter(symbolList, { 'exchange': exchange.code });
            const markets = [];
            // 交易所
            for (const exchange of ns_store_1.Store.data.ExchangeList) {
                // 交易市场
                const market = {
                    name: exchange.name,
                    submarkets: []
                };
                const marketList = lodash_1.filter(ns_store_1.Store.data.MarketList, { 'exchange': exchange.code });
                for (const ml of marketList) {
                    market.submarkets.push({
                        name: ml.name,
                        // 交易股票
                        symbols: lodash_1.filter(symbolList, { 'exchange': exchange.name, 'market': ml.name })
                    });
                }
                markets.push(market);
            }
            debug('getMarkets，获取市场数据方法[终了]');
            return markets;
        });
    }
    /**
    * 获取股票列表
    */
    getSymbolList() {
        return __awaiter(this, void 0, void 0, function* () {
            debug('getSymbolList，获取股票列表方法[启动]');
            const hesonogoma = new api_1.Hesonogoma();
            const count = yield ns_store_1.Store.model.SymbolInfo.count();
            debug('SymbolInfo表数据个数: ', count);
            // 数据库未找到股票信息
            if (count === 0) {
                // 通过api取数据
                const symbols = yield hesonogoma.getTseStocks();
                debug('数据库未找到股票信息,通过api获取数据个数: ', symbols.length);
                if (symbols && symbols.length !== 0) {
                    yield ns_store_1.Store.model.SymbolInfo.bulkCreate(symbols);
                }
            }
            const symbolList = yield ns_store_1.Store.model.SymbolInfo.findAll({
                // raw: true,
                attributes: ['symbol', 'exchange', 'market', 'name', 'type', 'sector'],
                include: [
                    {
                        model: ns_store_1.Store.model.Exchange,
                        attributes: ['name']
                    },
                    {
                        model: ns_store_1.Store.model.Market,
                        attributes: ['name'],
                        where: { exchange: 'TSE' }
                    },
                    {
                        model: ns_store_1.Store.model.Sector,
                        attributes: ['name'],
                        where: { exchange: 'TSE' }
                    }
                ],
                order: sequelize_typescript_1.Sequelize.col('symbol')
            });
            const plainSymbolList = symbolList.map((node) => {
                const plainNode = node.get({ plain: true });
                return {
                    symbol: plainNode.symbol,
                    exchange: plainNode.ex.name,
                    market: plainNode.ma.name,
                    name: plainNode.name,
                    type: plainNode.type,
                    sector: plainNode.se.name
                };
            });
            debug('取得数据个数：', plainSymbolList.length);
            debug('getSymbolList，获取股票列表方法[终了]');
            return plainSymbolList;
        });
    }
    /**
     * 获取最近半小时的5分钟K线数据
     */
    getLast5minBar(symbol) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.get5minBar({ symbol, date: moment().format('YYYY-MM-DD') });
        });
    }
    get5minBar(opt) {
        return __awaiter(this, void 0, void 0, function* () {
            let last30min = '';
            if (opt.date === moment().format('YYYY-MM-DD')) {
                last30min = `
        AND (
          STR_TO_DATE(created_at, '%Y-%m-%d %T') BETWEEN DATE_SUB(now(), INTERVAL 30 MINUTE)
          AND now()
        )
      `;
            }
            const res = yield ns_store_1.Store.sequelize.query(`
        SELECT
          t2.time,t2.open,t2.high,t2.low,t1.text close
        FROM
          dde t1
        JOIN (
          SELECT
            topic,
            CONCAT(UNIX_TIMESTAMP(DATE_FORMAT(
              FLOOR(
                STR_TO_DATE(created_at, '%Y-%m-%d %T') / 500
              ) * 500,
              '%Y-%m-%d %h:%i:%s'
            )),'000') time,  text open,max(text) high, min(text) low, MAX(created_at) last_time
          FROM
            dde
          WHERE
            item = '現在値'
            AND topic = '${opt.symbol}.T'
            AND date = '${opt.date}'
            ${last30min}
          GROUP BY
            DATE_FORMAT(
              FLOOR(
                STR_TO_DATE(created_at, '%Y-%m-%d %T') / 500
              ) * 500,
              '%H%i'
            )
        ORDER BY
          created_at DESC
        ) t2 on t1.created_at = t2.last_time
        WHERE
          t1.item = '現在値'
          AND t1.topic = '${opt.symbol}.T'
          AND t1.date = '${opt.date}'
    `, { type: ns_store_1.Store.sequelize.QueryTypes.SELECT });
            // 过滤数组
            return yield res.filter((bar) => bar.close);
        });
    }
    getStochastic(bars) {
        const closeList = [];
        const lowList = [];
        const highList = [];
        bars.forEach(bar => {
            closeList.push(bar.close);
            lowList.push(bar.low);
            highList.push(bar.high);
        });
        const input = {
            high: highList,
            low: lowList,
            close: closeList,
            period: 9,
            signalPeriod: 3
        };
        const kdList = technicalindicators_1.Stochastic.calculate(input);
        // 只截取算出kd的数组
        let proBars = bars.slice(bars.length - kdList.length, bars.length);
        // 四舍五入，去掉kd小数点
        proBars = proBars.map((bar, i) => {
            if (kdList[i].k !== undefined) {
                bar.k = Math.round(kdList[i].k);
            }
            if (kdList[i].d !== undefined) {
                bar.d = Math.round(kdList[i].d);
            }
            return bar;
        });
        return proBars;
    }
}
__decorate([
    ns_common_1.tryCatch('获取市场数据')
], DataProvider.prototype, "getMarkets", null);
__decorate([
    ns_common_1.tryCatch('获取股票列表')
], DataProvider.prototype, "getSymbolList", null);
exports.DataProvider = DataProvider;
